==> FHLBBS-4.2.tgz: wbbs/mlist.c <==
#include "cgic.h"
#include "wbbs.c"

int cgiMain() {
   FILE *fptr1,*fptr2, *fptr3;
   char buf1[256];
   char buf2[128];
   char *foo,board1[20],path1[100],curr_board[100];
   char oneline[301];
   char *bdname;
   time_t t1;
   int len1, fd, numposts, i=0,j, count, start = 999999, end1,delflag;
   struct fileheader postfile;
   struct stat st;
   boardheader *bp;
   boardheader *getbcache();
   int querymode=0;//=0 use number to query, =1 top =2 pgup =3 pgdn =4 bottom
   char *pt1,*pt2;
   int ptmode,showcnt;


   strncpy(curr_board,getenv("QUERY_STRING"),99);
   curr_board[99]=0;

   
   if(!check_passwd())
       return(0);

   if(strstr(curr_board,"delete")){
      delflag=1;
   }
   else{
      delflag=0;
   }
   if(foo = rindex(curr_board, '$')){
	if (strstr(curr_board,"top")) querymode=1;
        else if (strstr(curr_board,"pgup")) querymode=2;
        else if (strstr(curr_board,"pgdn")) querymode=3;
        else if (strstr(curr_board,"bottom")) querymode=4;
	else start = atoi(foo + 1);
	  *foo = '\0';
	if (start==0) start=Cookienumout;
   }

   if (strrchr(curr_board,'/')) //ȬOhacker
   {
      cgiHeaderContentType("text/html");
      fprintf(cgiOut,"<h1>AOhackerܡH</h1><p>\n");
      return(0);
   }
  
	strcpy(curr_board,"mail");
	bdname=curr_board;
      sprintf(path1,BBSHOME "/home/%s/.DIR", cuser.userid);

   if( stat(path1, &st ) >= 0 )
	  numposts = st.st_size / (sizeof( struct fileheader ));
   else
	  numposts = 0;

   if (querymode==2)
	start=(Cookienumout-SHOWNUM > 0) ? (Cookienumout-SHOWNUM) : 1;
   else if (querymode==3) 
      start=(Cookienumout+SHOWNUM < numposts-SHOWNUM) ? (Cookienumout+SHOWNUM) : numposts-SHOWNUM;
   else if (querymode==1) start=1;
   else if (querymode==4) start= numposts-SHOWNUM;

   if(start == 999999)
	  start = (numposts - SHOWNUM > 0) ? (numposts - SHOWNUM) : 1;
   else if(start <= 0)
	  start = 1;

   Cookienumin=start;
   if(!check_passwd())
       return(0);
   strcpy(buf1, curr_board);
  
   cgiHeaderContentType("text/html");
    /* o٭n@UA]nҼ{O_vAHΨCӪDiHק  */
   if(delflag==0)  
      sprintf(buf2, "%s%s",DEFDIR,MLISTDEF);
   else
      sprintf(buf2, "%s%s",DEFDIR,MDELDEF);

   if( (fptr2 = fopen(buf2,"r")) == NULL )
   {
     fprintf(cgiOut,"%sɮ׶}ҿ~<br>",buf2);
     return 0; 
     /************************************************************
      fprintf(cgiOut, "<html> <head><title>Document List</title></head>\n");
      fprintf(cgiOut, "<body text=\"#200020\" link=\"#ff0000\" "
       "alink=\"#0000ff\" vlink=\"#800080\" BGCOLOR=\"#D0FFB5\">\n");
      fprintf(cgiOut, "<font color=\"#ff0000\" size=6>MAIL List(default)"
       "</font>\n");
      fprintf(cgiOut, "<font size=4>\n");
      fprintf(cgiOut, "<a href=\"mlist.cgi?%s$top\"> Top </a>", curr_board);
      fprintf(cgiOut, "<a href=\"mlist.cgi?%s$pgup\"> Prev </a>", curr_board);
      fprintf(cgiOut, "<a href=\"mlist.cgi?%s$pgdn\"> Next </a>", curr_board);
      fprintf(cgiOut, "<a href=\"mlist.cgi?%s$bottom\"> Last </a>", curr_board);
      fprintf(cgiOut, "<a href=\"edit.cgi?board1=%s\"> Sent </a>",curr_board);
      **************************/
   }
   while(fgets(oneline, 300, fptr2) != NULL)
   {
    pt1=oneline;
      while (pt2=strstr(pt1,"<!--$"))
      {
         *pt2=0;
         pt2=pt2+5;
         fprintf(cgiOut,"%s", pt1);/* LXtokener */
         pt1=strstr(pt2,"-->");
         if (pt1==NULL) 
         {
            fprintf(cgiOut,"榡ɿ~IP@椺䤣 -->");
            return 0;
         }
         *pt1=0;
         pt1=pt1+3;
         ptmode=atoi(pt2);
         if (ptmode==0) //Dn\
         {
            //if(delflag==1)
            //   fprintf(cgiOut,"<form>");

            fprintf(cgiOut, "<table>");
            if(delflag==1){
               fprintf(cgiOut, "<tr><td>R</td><td>s</td><td>Ū</td><td>@</td>"
                      "<td></td><td>D</td></tr>\n");
            }
            else{
               fprintf(cgiOut, "<tr><td>s</td><td>Ū</td><td>@</td>"
                      "<td></td><td>D</td></tr>\n");
            }
             /* Ū .DIR  */
            sprintf(buf1,BBSHOME "/home/%s/.DIR", cuser.userid);
            if( (fd = open( buf1, O_RDONLY )) != -1 )
            {
             lseek(fd, sizeof(struct fileheader)*(start-1), SEEK_SET);
             end1 = (start + SHOWNUM > numposts) ? numposts : 
                    (start + SHOWNUM);
             showcnt=0;
             for(j = start;j <= end1;j++) 
             {
               read(fd,&postfile,sizeof(postfile));
               sscanf(postfile.filename,"M.%s.A",buf2);
               t1=atoi(buf2);
               strncpy(buf1,ctime(&t1)+4,6);
               buf1[6] = '\0';
               if (delflag==1){
                  showcnt++;
                  fprintf(cgiOut,"<tr><td><input name=\"m%d\" type=checkbox value=\"%d\"></td><td>%3d.</td><td>%s</td>"
                     "<td>%-15s</td><td>%-5s</td>"
                     ,showcnt,j,j, (postfile.filemode&FILE_READ)?"":"",postfile.owner,buf1);
               }
               else{
                  fprintf(cgiOut,"<tr><td>%3d.</td><td>%s</td>"
                     "<td>%-15s</td><td>%-5s</td>"
                     ,j, (postfile.filemode&FILE_READ)?"":"",postfile.owner,buf1);
               }
               fprintf(cgiOut,"<td><a href=\"read.cgi?%s_%d\">%s</a><td><tr>\n", 
               curr_board, j, postfile.title);
             } //for j
	         fprintf(cgiOut,"</table>");

             //if(delflag==1)
             //   fprintf(cgiOut,"</form>");

             close(fd);
             }/* endif(fd) */
             else
             { fprintf(cgiOut,"%sؿ}ҿ~I<p>",buf1);
             }
         }
         else // other mode
            SSI(ptmode);
       } // while pt1
     fprintf(cgiOut,"%s", pt1);
   } //while get oneline
      fclose(fptr2);

}

==> FHLBBS-4.8.tgz: wbbs/mlist.c <==
#include "cgic.h"
#include "wbbs.c"

int cgiMain() {
   FILE *fptr1,*fptr2, *fptr3;
   char buf1[256];
   char buf2[128];
   char *foo,board1[20],path1[100],curr_board[100];
   char oneline[301];
   char *bdname;
   time_t t1;
   int len1, fd, numposts, i=0,j, count, start = 999999, end1,delflag;
   struct fileheader postfile;
   struct stat st;
   boardheader *bp;
   boardheader *getbcache();
   int querymode=0;//=0 use number to query, =1 top =2 pgup =3 pgdn =4 bottom
   char *pt1,*pt2;
   int ptmode,showcnt;


   strncpy(curr_board,getenv("QUERY_STRING"),99);
   curr_board[99]=0;

   
   if(!check_passwd())
       return(0);

   if(strstr(curr_board,"delete")){
      delflag=1;
   }
   else{
      delflag=0;
   }
   if(foo = rindex(curr_board, '$')){
	if (strstr(curr_board,"top")) querymode=1;
        else if (strstr(curr_board,"pgup")) querymode=2;
        else if (strstr(curr_board,"pgdn")) querymode=3;
        else if (strstr(curr_board,"bottom")) querymode=4;
	else start = atoi(foo + 1);
	  *foo = '\0';
	if (start==0) start=Cookienumout;
   }

   if (strrchr(curr_board,'/')) //ȬOhacker
   {
      cgiHeaderContentType("text/html");
      fprintf(cgiOut,"<h1>AOhackerܡH</h1><p>\n");
      return(0);
   }
  
	strcpy(curr_board,"mail");
	bdname=curr_board;
      sprintf(path1,BBSHOME "/home/%s/.DIR", cuser.userid);

   if( stat(path1, &st ) >= 0 )
	  numposts = st.st_size / (sizeof( struct fileheader ));
   else
	  numposts = 0;

   if (querymode==2)
	start=(Cookienumout-SHOWNUM > 0) ? (Cookienumout-SHOWNUM) : 1;
   else if (querymode==3) 
      start=(Cookienumout+SHOWNUM < numposts-SHOWNUM) ? (Cookienumout+SHOWNUM) : numposts-SHOWNUM;
   else if (querymode==1) start=1;
   else if (querymode==4) start= numposts-SHOWNUM;

   if(start == 999999)
	  start = (numposts - SHOWNUM > 0) ? (numposts - SHOWNUM) : 1;
   else if(start <= 0)
	  start = 1;

   Cookienumin=start;
   if(!check_passwd())
       return(0);
   strcpy(buf1, curr_board);
  
   cgiHeaderContentType("text/html");
    /* o٭n@UA]nҼ{O_vAHΨCӪDiHק  */
   if(delflag==0)  
      sprintf(buf2, "%s%s",DEFDIR,MLISTDEF);
   else
      sprintf(buf2, "%s%s",DEFDIR,MDELDEF);

   if( (fptr2 = fopen(buf2,"r")) == NULL )
   {
     fprintf(cgiOut,"%sɮ׶}ҿ~<br>",buf2);
     return 0; 
     /************************************************************
      fprintf(cgiOut, "<html> <head><title>Document List</title></head>\n");
      fprintf(cgiOut, "<body text=\"#200020\" link=\"#ff0000\" "
       "alink=\"#0000ff\" vlink=\"#800080\" BGCOLOR=\"#D0FFB5\">\n");
      fprintf(cgiOut, "<font color=\"#ff0000\" size=6>MAIL List(default)"
       "</font>\n");
      fprintf(cgiOut, "<font size=4>\n");
      fprintf(cgiOut, "<a href=\"mlist.cgi?%s$top\"> Top </a>", curr_board);
      fprintf(cgiOut, "<a href=\"mlist.cgi?%s$pgup\"> Prev </a>", curr_board);
      fprintf(cgiOut, "<a href=\"mlist.cgi?%s$pgdn\"> Next </a>", curr_board);
      fprintf(cgiOut, "<a href=\"mlist.cgi?%s$bottom\"> Last </a>", curr_board);
      fprintf(cgiOut, "<a href=\"edit.cgi?board1=%s\"> Sent </a>",curr_board);
      **************************/
   }
   while(fgets(oneline, 300, fptr2) != NULL)
   {
    pt1=oneline;
      while (pt2=strstr(pt1,"<!--$"))
      {
         *pt2=0;
         pt2=pt2+5;
         fprintf(cgiOut,"%s", pt1);/* LXtokener */
         pt1=strstr(pt2,"-->");
         if (pt1==NULL) 
         {
            fprintf(cgiOut,"榡ɿ~IP@椺䤣 -->");
            return 0;
         }
         *pt1=0;
         pt1=pt1+3;
         ptmode=atoi(pt2);
         if (ptmode==0) //Dn\
         {
            //if(delflag==1)
            //   fprintf(cgiOut,"<form>");

            fprintf(cgiOut, "<table>");
            if(delflag==1){
               fprintf(cgiOut, "<tr><td>R</td><td>s</td><td>Ū</td><td>@</td>"
                      "<td></td><td>D</td></tr>\n");
            }
            else{
               fprintf(cgiOut, "<tr><td>s</td><td>Ū</td><td>@</td>"
                      "<td></td><td>D</td></tr>\n");
            }
             /* Ū .DIR  */
            sprintf(buf1,BBSHOME "/home/%s/.DIR", cuser.userid);
            if( (fd = open( buf1, O_RDONLY )) != -1 )
            {
             lseek(fd, sizeof(struct fileheader)*(start-1), SEEK_SET);
             end1 = (start + SHOWNUM > numposts) ? numposts : 
                    (start + SHOWNUM);
             showcnt=0;
             for(j = start;j <= end1;j++) 
             {
               read(fd,&postfile,sizeof(postfile));
               sscanf(postfile.filename,"M.%s.A",buf2);
               t1=atoi(buf2);
               strncpy(buf1,ctime(&t1)+4,6);
               buf1[6] = '\0';
               if (delflag==1){
                  showcnt++;
                  fprintf(cgiOut,"<tr><td><input name=\"m%d\" type=checkbox value=\"%d\"></td><td>%3d.</td><td>%s</td>"
                     "<td>%-15s</td><td>%-5s</td>"
                     ,showcnt,j,j, (postfile.filemode&FILE_READ)?"":"",postfile.owner,buf1);
               }
               else{
                  fprintf(cgiOut,"<tr><td>%3d.</td><td>%s</td>"
                     "<td>%-15s</td><td>%-5s</td>"
                     ,j, (postfile.filemode&FILE_READ)?"":"",postfile.owner,buf1);
               }
               fprintf(cgiOut,"<td><a href=\"read.cgi?%s_%d\">%s</a><td><tr>\n", 
               curr_board, j, postfile.title[0]?postfile.title:"LD");
             } //for j
	         fprintf(cgiOut,"</table>");

             //if(delflag==1)
             //   fprintf(cgiOut,"</form>");

             close(fd);
             }/* endif(fd) */
             else
             { fprintf(cgiOut,"%sؿ}ҿ~I<p>",buf1);
             }
         }
         else // other mode
            SSI(ptmode);
       } // while pt1
     fprintf(cgiOut,"%s", pt1);
   } //while get oneline
      fclose(fptr2);

}
